@@ -2,15 +2,15 @@
 //
 // KRotation screen saver for KDE
 // Copyright (C) 2004 Georg Drenkhahn
-// $Id: sspreviewarea.cpp 304354 2004-04-16 23:42:39Z kniederk $
+// $Id: sspreviewarea.cpp 753878 2007-12-28 17:37:07Z uwolfer $
 //
 //============================================================================
 
 #include "sspreviewarea.h"
 #include "sspreviewarea.moc"
 
-SsPreviewArea::SsPreviewArea(QWidget* parent, const char* name)
-   : QWidget(parent, name)
+SsPreviewArea::SsPreviewArea(QWidget* parent)
+   : QWidget(parent)
 {
 }
 
