@@ -1,7 +1,7 @@
 //============================================================================
 //
 // 3-dim real vector class
-// $Id: vec3.cpp 324707 2004-06-29 19:44:18Z fawcett $
+// $Id: vec3.cpp 631395 2007-02-07 22:34:02Z dfaure $
 // Copyright (C) 2004 Georg Drenkhahn
 //
 // This file is free software; you can redistribute it and/or modify it under
@@ -25,8 +25,9 @@ static inline double nan__()
 #   define NAN (::nan__())
 #endif
 
-#include <config.h>
+#include <config-kdesavers.h>
 
+/* TODO define it */
 #ifdef HAVE_NUMERIC_LIMITS
 #include <limits>
 #endif
