@@ -16,16 +16,15 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; see the file COPYING.  If not, write to
-// the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-// Boston, MA 02111-1307, USA.
-
-#include <config.h>
+// the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+// Boston, MA 02110-1301, USA.
+#include <config-kxsconfig.h>
 
 #include <stdlib.h>
 #include <stdio.h>
 #include <unistd.h>
 
-#include <qptrlist.h>
+#include <q3ptrlist.h>
 #include <qfile.h>
 #include <qfileinfo.h>
 
@@ -41,30 +40,30 @@
 
 #define MAX_ARGS  30
 
-template class QPtrList<KXSConfigItem>;
+template class Q3PtrList<KXSConfigItem>;
 
 //===========================================================================
-static const char *appName = "kxsrun";
+static const char appName[] = "kxsrun";
 
-static const char *description = I18N_NOOP("KDE X Screen Saver Launcher");
+static const char description[] = I18N_NOOP("KDE X Screen Saver Launcher");
 
-static const char *version = "3.0.0";
-
-static const KCmdLineOptions options[] =
-{
-   {"+screensaver", I18N_NOOP("Filename of the screen saver to start"), 0},
-   {"+-- [options]", I18N_NOOP("Extra options to pass to the screen saver"), 0},
-   KCmdLineLastOption
-};
+static const char version[] = "3.0.0";
 
 int main(int argc, char *argv[])
 {
-    KLocale::setMainCatalogue("kxsconfig");
-    KCmdLineArgs::init(argc, argv, appName, description, version);
+    KLocale::setMainCatalog("kxsconfig");
+    KCmdLineArgs::init(argc, argv, appName, 0, ki18n("KXSRun"), version, ki18n(description));
+
+
+    KCmdLineOptions options;
+
+    options.add("+screensaver", ki18n("Filename of the screen saver to start"));
+
+    options.add("+-- [options]", ki18n("Extra options to pass to the screen saver"));
 
     KCmdLineArgs::addCmdLineOptions(options);
 
-    KApplication app( false, false );
+    KApplication app( false );
 
     KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
@@ -85,7 +84,7 @@ int main(int argc, char *argv[])
     // read configuration args
     KConfig config(configFile);
 
-    QPtrList<KXSConfigItem> configItemList;
+    Q3PtrList<KXSConfigItem> configItemList;
 
     QString xmlFile = "/doesntexist";
 #ifdef XSCREENSAVER_CONFIG_DIR
@@ -97,7 +96,7 @@ int main(int argc, char *argv[])
 	KXSXml xmlParser(0);
 	xmlParser.parse(xmlFile);
 	configItemList = *xmlParser.items();
-	QPtrListIterator<KXSConfigItem> it( configItemList );
+	Q3PtrListIterator<KXSConfigItem> it( configItemList );
 	KXSConfigItem *item;
 	while ( (item = it.current()) != 0 ) {
 	    ++it;
@@ -110,8 +109,8 @@ int main(int argc, char *argv[])
 	{
 	    QString group = QString("Arg%1").arg(idx);
 	    if (config.hasGroup(group)) {
-		config.setGroup(group);
-		QString type = config.readEntry("Type");
+                KConfigGroup grp = config.group(group);
+		QString type = grp.readEntry("Type");
 		if (type == "Range") {
 		    KXSRangeItem *rc = new KXSRangeItem(group, config);
 		    configItemList.append(rc);
@@ -136,7 +135,7 @@ int main(int argc, char *argv[])
     //work around a KStandarDirs::findExe() "feature" where it looks in $KDEDIR/bin first no matter what and sometimes finds the wrong executable
     QFileInfo checkExe;
     QString saverdir = QString("%1/%2").arg(XSCREENSAVER_HACKS_DIR).arg(filename);
-    kdDebug() << "saverdir is" << saverdir << endl;
+    kDebug() << "saverdir is" << saverdir;
     QString exeFile;
     checkExe.setFile(saverdir);
     if (checkExe.exists() && checkExe.isExecutable() && checkExe.isFile())
